@@ -26,7 +26,7 @@ class SlottedGeometry(Geometry):
         calculate_layer_radii(self)
         calculate_positioning_angle_for_first_block_of_each_layer(self)
 
-    def init_geometry_instance(self, blocks, geometry):
+    def init_rel_geometry_instance(self, blocks, geometry):
         return SlottedRelativeCosThetaGeometry(r_aperture=self.r_aperture,
                                                blocks=blocks,
                                                layer_defs=geometry.layer_defs)
@@ -92,7 +92,7 @@ class SlottedRelativeCosThetaGeometry(RelativeCosThetaGeometry):
         calculate_layer_radii(self)
         calculate_positioning_angle_for_first_block_of_each_layer(self)
 
-    def init_geometry_instance(self, blocks, layer_defs):
+    def init_rel_geometry_instance(self, blocks, layer_defs):
         return SlottedGeometry(r_aperture=self.r_aperture, blocks=blocks, layer_defs=layer_defs)
 
     def init_geometry_dict(self, block_defs, layer_defs):
