@@ -2,6 +2,7 @@ from typing import Tuple, Union
 from dataclasses import dataclass
 
 import pandas as pd
+from shapely.geometry import Polygon
 import matplotlib.pyplot as plt
 
 from magnumapi.geometry.primitives.Arc import Arc
@@ -197,9 +198,6 @@ class Area:
 
     @staticmethod
     def are_areas_overlapping(area_a: "Area", area_b: "Area") -> True:
-        line_a = area_a.get_line(2)
-        line_a_rev = Line.of_end_points(line_a.p2, line_a.p1)
-        orient_p1 = Line.calculate_point_orientation_wrt_line(line_a_rev, area_b.get_line(0).p1)
-        orient_p2 = Line.calculate_point_orientation_wrt_line(line_a_rev, area_b.get_line(0).p2)
-
-        return orient_p1 == -1 or orient_p2 == -1
+        p1 = Polygon([(area_a.get_line(i).p1.x, area_a.get_line(i).p1.y) for i in range(4)])
+        p2 = Polygon([(area_b.get_line(i).p1.x, area_b.get_line(i).p1.y) for i in range(4)])
+        return p1.intersects(p2)
